pub struct PositionInverted {Show 14 fields
pub perpId: U256,
pub accountId: U256,
pub positionType: <PositionEnum as SolType>::RustType,
pub leverageHdths: U256,
pub startDepositCNS: U256,
pub endDepositCNS: U256,
pub pnlCollateralizedCNS: I256,
pub pricePNS: U256,
pub startLotLNS: U256,
pub endLotLNS: U256,
pub deltaPnlCNS: I256,
pub fundingCNS: I256,
pub insFeeCNS: U256,
pub protFeeCNS: U256,
}Expand description
Event with signature PositionInverted(uint256,uint256,uint8,uint256,uint256,uint256,int256,uint256,uint256,uint256,int256,int256,uint256,uint256) and selector 0x01a0596385c75b269e896ca6468a2be2edc8b2b5459f4e25ca0a75944390a10c.
event PositionInverted(uint256 perpId, uint256 accountId, PositionEnum positionType, uint256 leverageHdths, uint256 startDepositCNS, uint256 endDepositCNS, int256 pnlCollateralizedCNS, uint256 pricePNS, uint256 startLotLNS, uint256 endLotLNS, int256 deltaPnlCNS, int256 fundingCNS, uint256 insFeeCNS, uint256 protFeeCNS);Fields
perpId: U256accountId: U256positionType: <PositionEnum as SolType>::RustTypeleverageHdths: U256startDepositCNS: U256endDepositCNS: U256pnlCollateralizedCNS: I256pricePNS: U256startLotLNS: U256endLotLNS: U256deltaPnlCNS: I256fundingCNS: I256insFeeCNS: U256protFeeCNS: U256Trait Implementations
Sourceimpl Clone for PositionInverted
impl Clone for PositionInverted
Sourcefn clone(&self) -> PositionInverted
fn clone(&self) -> PositionInverted
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PositionInverted
impl Debug for PositionInverted
Sourceimpl From<&PositionInverted> for LogData
impl From<&PositionInverted> for LogData
Sourcefn from(this: &PositionInverted) -> LogData
fn from(this: &PositionInverted) -> LogData
Converts to this type from the input type.
Sourceimpl IntoLogData for PositionInverted
impl IntoLogData for PositionInverted
Sourcefn to_log_data(&self) -> LogData
fn to_log_data(&self) -> LogData
Convert into a
LogData object.Sourcefn into_log_data(self) -> LogData
fn into_log_data(self) -> LogData
Consume and convert into a
LogData object.Sourceimpl SolEvent for PositionInverted
impl SolEvent for PositionInverted
Sourceconst SIGNATURE: &'static str = "PositionInverted(uint256,uint256,uint8,uint256,uint256,uint256,int256,uint256,uint256,uint256,int256,int256,uint256,uint256)"
const SIGNATURE: &'static str = "PositionInverted(uint256,uint256,uint8,uint256,uint256,uint256,int256,uint256,uint256,uint256,int256,int256,uint256,uint256)"
The event’s ABI signature. Read more
Sourceconst SIGNATURE_HASH: B256
const SIGNATURE_HASH: B256
The event’s ABI signature hash, or selector:
keccak256(SIGNATURE) Read moreSourcetype DataTuple<'a> = (Uint<256>, Uint<256>, PositionEnum, Uint<256>, Uint<256>, Uint<256>, Int<256>, Uint<256>, Uint<256>, Uint<256>, Int<256>, Int<256>, Uint<256>, Uint<256>)
type DataTuple<'a> = (Uint<256>, Uint<256>, PositionEnum, Uint<256>, Uint<256>, Uint<256>, Int<256>, Uint<256>, Uint<256>, Uint<256>, Int<256>, Int<256>, Uint<256>, Uint<256>)
The underlying tuple type which represents this event’s non-indexed
parameters. These parameters are ABI encoded and included in the log
body. Read more
Sourcetype DataToken<'a> = <<PositionInverted as SolEvent>::DataTuple<'a> as SolType>::Token<'a>
type DataToken<'a> = <<PositionInverted as SolEvent>::DataTuple<'a> as SolType>::Token<'a>
The
TokenSeq type corresponding to the tuple.Sourcetype TopicList = (FixedBytes<32>,)
type TopicList = (FixedBytes<32>,)
The underlying tuple type which represents this event’s topics. Read more
Sourcefn new(
topics: <Self::TopicList as SolType>::RustType,
data: <Self::DataTuple<'_> as SolType>::RustType,
) -> Self
fn new( topics: <Self::TopicList as SolType>::RustType, data: <Self::DataTuple<'_> as SolType>::RustType, ) -> Self
Convert decoded rust data to the event type. Read more
Sourcefn check_signature(
topics: &<Self::TopicList as SolType>::RustType,
) -> Result<()>
fn check_signature( topics: &<Self::TopicList as SolType>::RustType, ) -> Result<()>
Check that the event’s signature matches the given topics.
Sourcefn tokenize_body(&self) -> Self::DataToken<'_>
fn tokenize_body(&self) -> Self::DataToken<'_>
Tokenize the event’s non-indexed parameters.
Sourcefn encode_topics_raw(&self, out: &mut [WordToken]) -> Result<()>
fn encode_topics_raw(&self, out: &mut [WordToken]) -> Result<()>
Encode the topics of this event into the given buffer. Read more
Sourcefn new_checked(
topics: <Self::TopicList as SolType>::RustType,
data: <Self::DataTuple<'_> as SolType>::RustType,
) -> Result<Self, Error>
fn new_checked( topics: <Self::TopicList as SolType>::RustType, data: <Self::DataTuple<'_> as SolType>::RustType, ) -> Result<Self, Error>
Convert decoded rust data to the event type. Read more
Sourcefn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the ABI-encoded dynamic data in bytes.
Sourcefn encode_data_to(&self, out: &mut Vec<u8>)
fn encode_data_to(&self, out: &mut Vec<u8>)
ABI-encode the dynamic data of this event into the given buffer.
Sourcefn encode_topics_array<const LEN: usize>(&self) -> [WordToken; LEN]
fn encode_topics_array<const LEN: usize>(&self) -> [WordToken; LEN]
Encode the topics of this event into a fixed-size array. Read more
Sourcefn encode_log_data(&self) -> LogData
fn encode_log_data(&self) -> LogData
Encode this event to a
LogData.Sourcefn encode_log(log: &Log<Self>) -> Log
fn encode_log(log: &Log<Self>) -> Log
Sourcefn decode_topics<I, D>(
topics: I,
) -> Result<<Self::TopicList as SolType>::RustType, Error>
fn decode_topics<I, D>( topics: I, ) -> Result<<Self::TopicList as SolType>::RustType, Error>
Decode the topics of this event from the given data.
Sourcefn abi_decode_data<'a>(
data: &'a [u8],
) -> Result<<Self::DataTuple<'a> as SolType>::RustType, Error>
fn abi_decode_data<'a>( data: &'a [u8], ) -> Result<<Self::DataTuple<'a> as SolType>::RustType, Error>
ABI-decodes the dynamic data of this event from the given buffer.
Sourcefn abi_decode_data_validate<'a>(
data: &'a [u8],
) -> Result<<Self::DataTuple<'a> as SolType>::RustType, Error>
fn abi_decode_data_validate<'a>( data: &'a [u8], ) -> Result<<Self::DataTuple<'a> as SolType>::RustType, Error>
ABI-decodes the dynamic data of this event from the given buffer, with validation. Read more
Sourcefn decode_raw_log<I, D>(topics: I, data: &[u8]) -> Result<Self, Error>
fn decode_raw_log<I, D>(topics: I, data: &[u8]) -> Result<Self, Error>
Decode the event from the given log info.
Sourcefn decode_raw_log_validate<I, D>(topics: I, data: &[u8]) -> Result<Self, Error>
fn decode_raw_log_validate<I, D>(topics: I, data: &[u8]) -> Result<Self, Error>
Decode the event from the given log info, with validation. Read more
Sourcefn decode_log_data(log: &LogData) -> Result<Self, Error>
fn decode_log_data(log: &LogData) -> Result<Self, Error>
Decode the event from the given log object.
Sourcefn decode_log_data_validate(log: &LogData) -> Result<Self, Error>
fn decode_log_data_validate(log: &LogData) -> Result<Self, Error>
Decode the event from the given log object with validation.