pub struct initializeV2Call {
pub configs: Vec<<PerpScalingConfig as SolType>::RustType>,
pub residueTransfers: Vec<<ResidueTransfer as SolType>::RustType>,
}Expand description
Function with signature initializeV2((uint256,uint256)[],(uint256,uint256)[]) and selector 0x065db330.
function initializeV2(PerpScalingConfig[] memory configs, ResidueTransfer[] memory residueTransfers) external;Fields
configs: Vec<<PerpScalingConfig as SolType>::RustType>residueTransfers: Vec<<ResidueTransfer as SolType>::RustType>Trait Implementations
Sourceimpl Clone for initializeV2Call
impl Clone for initializeV2Call
Sourcefn clone(&self) -> initializeV2Call
fn clone(&self) -> initializeV2Call
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for initializeV2Call
impl Debug for initializeV2Call
Sourceimpl SolCall for initializeV2Call
impl SolCall for initializeV2Call
Sourceconst SIGNATURE: &'static str = "initializeV2((uint256,uint256)[],(uint256,uint256)[])"
const SIGNATURE: &'static str = "initializeV2((uint256,uint256)[],(uint256,uint256)[])"
The function’s ABI signature.
Sourcetype Parameters<'a> = (Array<PerpScalingConfig>, Array<ResidueTransfer>)
type Parameters<'a> = (Array<PerpScalingConfig>, Array<ResidueTransfer>)
The underlying tuple type which represents this type’s arguments. Read more
Sourcetype Token<'a> = <<initializeV2Call as SolCall>::Parameters<'a> as SolType>::Token<'a>
type Token<'a> = <<initializeV2Call as SolCall>::Parameters<'a> as SolType>::Token<'a>
The arguments’ corresponding TokenSeq type.
Sourcetype Return = initializeV2Return
type Return = initializeV2Return
The function’s return struct.
Sourcetype ReturnTuple<'a> = ()
type ReturnTuple<'a> = ()
The underlying tuple type which represents this type’s return values. Read more
Sourcetype ReturnToken<'a> = <<initializeV2Call as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
type ReturnToken<'a> = <<initializeV2Call as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
The returns’ corresponding TokenSeq type.
Sourcefn new<'a>(tuple: <Self::Parameters<'a> as SolType>::RustType) -> Self
fn new<'a>(tuple: <Self::Parameters<'a> as SolType>::RustType) -> Self
Convert from the tuple type used for ABI encoding and decoding.
Sourcefn tokenize_returns(ret: &Self::Return) -> Self::ReturnToken<'_>
fn tokenize_returns(ret: &Self::Return) -> Self::ReturnToken<'_>
Tokenize the call’s return values.
Sourcefn abi_decode_returns(data: &[u8]) -> Result<Self::Return>
fn abi_decode_returns(data: &[u8]) -> Result<Self::Return>
ABI decode this call’s return values from the given slice.
Sourcefn abi_decode_returns_validate(data: &[u8]) -> Result<Self::Return>
fn abi_decode_returns_validate(data: &[u8]) -> Result<Self::Return>
ABI decode this call’s return values from the given slice, with validation. Read more
Sourcefn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the encoded data in bytes, without its selector.
Sourcefn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector.
Sourcefn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector, with validation. Read more
Sourcefn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector.
Sourcefn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector, with validation. Read more
Sourcefn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
ABI encode the call to the given buffer without its selector.
Sourcefn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
fn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
ABI encode the call’s return values.