pub struct initializeV3Call {
pub defaultTakerFeesPer100K: [U256; 8],
pub defaultMakerFeesPer100K: [U256; 8],
pub rwaTakerFeesPer100K: [U256; 8],
pub rwaMakerFeesPer100K: [U256; 8],
pub existingPerpIds: Vec<U256>,
}Expand description
Function with signature initializeV3(uint256[8],uint256[8],uint256[8],uint256[8],uint256[]) and selector 0x63139803.
function initializeV3(uint256[8] memory defaultTakerFeesPer100K, uint256[8] memory defaultMakerFeesPer100K, uint256[8] memory rwaTakerFeesPer100K, uint256[8] memory rwaMakerFeesPer100K, uint256[] memory existingPerpIds) external;Fields
defaultTakerFeesPer100K: [U256; 8]defaultMakerFeesPer100K: [U256; 8]rwaTakerFeesPer100K: [U256; 8]rwaMakerFeesPer100K: [U256; 8]existingPerpIds: Vec<U256>Trait Implementations
Sourceimpl Clone for initializeV3Call
impl Clone for initializeV3Call
Sourcefn clone(&self) -> initializeV3Call
fn clone(&self) -> initializeV3Call
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for initializeV3Call
impl Debug for initializeV3Call
Sourceimpl SolCall for initializeV3Call
impl SolCall for initializeV3Call
Sourceconst SIGNATURE: &'static str = "initializeV3(uint256[8],uint256[8],uint256[8],uint256[8],uint256[])"
const SIGNATURE: &'static str = "initializeV3(uint256[8],uint256[8],uint256[8],uint256[8],uint256[])"
The function’s ABI signature.
Sourcetype Parameters<'a> = (FixedArray<Uint<256>, 8>, FixedArray<Uint<256>, 8>, FixedArray<Uint<256>, 8>, FixedArray<Uint<256>, 8>, Array<Uint<256>>)
type Parameters<'a> = (FixedArray<Uint<256>, 8>, FixedArray<Uint<256>, 8>, FixedArray<Uint<256>, 8>, FixedArray<Uint<256>, 8>, Array<Uint<256>>)
The underlying tuple type which represents this type’s arguments. Read more
Sourcetype Token<'a> = <<initializeV3Call as SolCall>::Parameters<'a> as SolType>::Token<'a>
type Token<'a> = <<initializeV3Call as SolCall>::Parameters<'a> as SolType>::Token<'a>
The arguments’ corresponding TokenSeq type.
Sourcetype Return = initializeV3Return
type Return = initializeV3Return
The function’s return struct.
Sourcetype ReturnTuple<'a> = ()
type ReturnTuple<'a> = ()
The underlying tuple type which represents this type’s return values. Read more
Sourcetype ReturnToken<'a> = <<initializeV3Call as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
type ReturnToken<'a> = <<initializeV3Call as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
The returns’ corresponding TokenSeq type.
Sourcefn new<'a>(tuple: <Self::Parameters<'a> as SolType>::RustType) -> Self
fn new<'a>(tuple: <Self::Parameters<'a> as SolType>::RustType) -> Self
Convert from the tuple type used for ABI encoding and decoding.
Sourcefn tokenize_returns(ret: &Self::Return) -> Self::ReturnToken<'_>
fn tokenize_returns(ret: &Self::Return) -> Self::ReturnToken<'_>
Tokenize the call’s return values.
Sourcefn abi_decode_returns(data: &[u8]) -> Result<Self::Return>
fn abi_decode_returns(data: &[u8]) -> Result<Self::Return>
ABI decode this call’s return values from the given slice.
Sourcefn abi_decode_returns_validate(data: &[u8]) -> Result<Self::Return>
fn abi_decode_returns_validate(data: &[u8]) -> Result<Self::Return>
ABI decode this call’s return values from the given slice, with validation. Read more
Sourcefn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the encoded data in bytes, without its selector.
Sourcefn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector.
Sourcefn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector, with validation. Read more
Sourcefn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector.
Sourcefn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector, with validation. Read more
Sourcefn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
ABI encode the call to the given buffer without its selector.
Sourcefn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
fn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
ABI encode the call’s return values.