pub struct CloseOrderPositionMismatch {
pub positionType: <PositionEnum as SolType>::RustType,
pub orderType: <OrderEnum as SolType>::RustType,
}Expand description
Custom error with signature CloseOrderPositionMismatch(uint8,uint8) and selector 0x189a4ff8.
error CloseOrderPositionMismatch(PositionEnum positionType, OrderEnum orderType);Fields
positionType: <PositionEnum as SolType>::RustTypeorderType: <OrderEnum as SolType>::RustTypeTrait Implementations
Sourceimpl Clone for CloseOrderPositionMismatch
impl Clone for CloseOrderPositionMismatch
Sourcefn clone(&self) -> CloseOrderPositionMismatch
fn clone(&self) -> CloseOrderPositionMismatch
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CloseOrderPositionMismatch
impl Debug for CloseOrderPositionMismatch
Sourceimpl SolError for CloseOrderPositionMismatch
impl SolError for CloseOrderPositionMismatch
Sourceconst SIGNATURE: &'static str = "CloseOrderPositionMismatch(uint8,uint8)"
const SIGNATURE: &'static str = "CloseOrderPositionMismatch(uint8,uint8)"
The error’s ABI signature.
Sourcetype Parameters<'a> = (PositionEnum, OrderEnum)
type Parameters<'a> = (PositionEnum, OrderEnum)
The underlying tuple type which represents the error’s members. Read more
Sourcetype Token<'a> = <<CloseOrderPositionMismatch as SolError>::Parameters<'a> as SolType>::Token<'a>
type Token<'a> = <<CloseOrderPositionMismatch as SolError>::Parameters<'a> as SolType>::Token<'a>
The corresponding
TokenSeq type.Sourcefn new<'a>(tuple: <Self::Parameters<'a> as SolType>::RustType) -> Self
fn new<'a>(tuple: <Self::Parameters<'a> as SolType>::RustType) -> Self
Convert from the tuple type used for ABI encoding and decoding.
Sourcefn tokenize(&self) -> Self::Token<'_>
fn tokenize(&self) -> Self::Token<'_>
Convert to the token type used for EIP-712 encoding and decoding.
Sourcefn abi_decode_raw_validate(data: &[u8]) -> Result<Self>
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self>
ABI decode this error’s arguments from the given slice, without its
selector, with validation. Read more
Sourcefn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the error params when encoded in bytes, without the
selector.
Sourcefn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector.
Sourcefn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
ABI decode this error’s arguments from the given slice, with the
selector.
Sourcefn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this error’s arguments from the given slice, with the
selector, with validation. Read more
Sourcefn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
ABI encode the error to the given buffer without its selector.