pub struct TestTokenInstance<P, N = Ethereum> { /* private fields */ }Expand description
A TestToken instance.
Contains type-safe methods for interacting with an on-chain instance of the
TestToken contract located at a given address, using a given
provider P.
If the contract bytecode is available (see the sol!
documentation on how to provide it), the deploy and deploy_builder methods can
be used to deploy a new instance of the contract.
See the module-level documentation for all the available methods.
Implementations
Sourceimpl<P: Provider<N>, N: Network> TestTokenInstance<P, N>
Instantiation and getters/setters.
impl<P: Provider<N>, N: Network> TestTokenInstance<P, N>
Instantiation and getters/setters.
Sourcepub const fn new(address: Address, __provider: P) -> Self
pub const fn new(address: Address, __provider: P) -> Self
Creates a new wrapper around an on-chain TestToken contract instance.
See the wrapper’s documentation for more details.
Sourcepub async fn deploy(
__provider: P,
_name: String,
_symbol: String,
_decimals: u8,
) -> Result<TestTokenInstance<P, N>>
pub async fn deploy( __provider: P, _name: String, _symbol: String, _decimals: u8, ) -> Result<TestTokenInstance<P, N>>
Deploys this contract using the given provider and constructor arguments, if any.
Returns a new instance of the contract, if the deployment was successful.
For more fine-grained control over the deployment process, use deploy_builder instead.
Sourcepub fn deploy_builder(
__provider: P,
_name: String,
_symbol: String,
_decimals: u8,
) -> RawCallBuilder<P, N>
pub fn deploy_builder( __provider: P, _name: String, _symbol: String, _decimals: u8, ) -> RawCallBuilder<P, N>
Creates a RawCallBuilder for deploying this contract using the given provider
and constructor arguments, if any.
This is a simple wrapper around creating a RawCallBuilder with the data set to
the bytecode concatenated with the constructor’s ABI-encoded arguments.
Sourcepub fn set_address(&mut self, address: Address)
pub fn set_address(&mut self, address: Address)
Sets the address.
Sourceimpl<P: Clone, N> TestTokenInstance<&P, N>
impl<P: Clone, N> TestTokenInstance<&P, N>
Sourcepub fn with_cloned_provider(self) -> TestTokenInstance<P, N>
pub fn with_cloned_provider(self) -> TestTokenInstance<P, N>
Clones the provider and returns a new instance with the cloned provider.
Sourceimpl<P: Provider<N>, N: Network> TestTokenInstance<P, N>
Function calls.
impl<P: Provider<N>, N: Network> TestTokenInstance<P, N>
Function calls.
Sourcepub fn call_builder<C: SolCall>(&self, call: &C) -> SolCallBuilder<&P, C, N>
pub fn call_builder<C: SolCall>(&self, call: &C) -> SolCallBuilder<&P, C, N>
Creates a new call builder using this contract instance’s provider and address.
Note that the call can be any function call, not just those defined in this contract. Prefer using the other methods for building type-safe contract calls.
Sourcepub fn allowance(
&self,
owner: Address,
spender: Address,
) -> SolCallBuilder<&P, allowanceCall, N>
pub fn allowance( &self, owner: Address, spender: Address, ) -> SolCallBuilder<&P, allowanceCall, N>
Creates a new call builder for the [allowance] function.
Sourcepub fn approve(
&self,
spender: Address,
amount: U256,
) -> SolCallBuilder<&P, approveCall, N>
pub fn approve( &self, spender: Address, amount: U256, ) -> SolCallBuilder<&P, approveCall, N>
Creates a new call builder for the [approve] function.
Sourcepub fn balanceOf(
&self,
account: Address,
) -> SolCallBuilder<&P, balanceOfCall, N>
pub fn balanceOf( &self, account: Address, ) -> SolCallBuilder<&P, balanceOfCall, N>
Creates a new call builder for the [balanceOf] function.
Sourcepub fn decimals(&self) -> SolCallBuilder<&P, decimalsCall, N>
pub fn decimals(&self) -> SolCallBuilder<&P, decimalsCall, N>
Creates a new call builder for the [decimals] function.
Sourcepub fn decreaseAllowance(
&self,
spender: Address,
subtractedValue: U256,
) -> SolCallBuilder<&P, decreaseAllowanceCall, N>
pub fn decreaseAllowance( &self, spender: Address, subtractedValue: U256, ) -> SolCallBuilder<&P, decreaseAllowanceCall, N>
Creates a new call builder for the [decreaseAllowance] function.
Sourcepub fn increaseAllowance(
&self,
spender: Address,
addedValue: U256,
) -> SolCallBuilder<&P, increaseAllowanceCall, N>
pub fn increaseAllowance( &self, spender: Address, addedValue: U256, ) -> SolCallBuilder<&P, increaseAllowanceCall, N>
Creates a new call builder for the [increaseAllowance] function.
Sourcepub fn mint(
&self,
account: Address,
amount: U256,
) -> SolCallBuilder<&P, mintCall, N>
pub fn mint( &self, account: Address, amount: U256, ) -> SolCallBuilder<&P, mintCall, N>
Creates a new call builder for the [mint] function.
Sourcepub fn name(&self) -> SolCallBuilder<&P, nameCall, N>
pub fn name(&self) -> SolCallBuilder<&P, nameCall, N>
Creates a new call builder for the [name] function.
Sourcepub fn symbol(&self) -> SolCallBuilder<&P, symbolCall, N>
pub fn symbol(&self) -> SolCallBuilder<&P, symbolCall, N>
Creates a new call builder for the [symbol] function.
Sourcepub fn totalSupply(&self) -> SolCallBuilder<&P, totalSupplyCall, N>
pub fn totalSupply(&self) -> SolCallBuilder<&P, totalSupplyCall, N>
Creates a new call builder for the [totalSupply] function.
Sourcepub fn transfer(
&self,
to: Address,
amount: U256,
) -> SolCallBuilder<&P, transferCall, N>
pub fn transfer( &self, to: Address, amount: U256, ) -> SolCallBuilder<&P, transferCall, N>
Creates a new call builder for the [transfer] function.
Sourcepub fn transferFrom(
&self,
from: Address,
to: Address,
amount: U256,
) -> SolCallBuilder<&P, transferFromCall, N>
pub fn transferFrom( &self, from: Address, to: Address, amount: U256, ) -> SolCallBuilder<&P, transferFromCall, N>
Creates a new call builder for the [transferFrom] function.
Sourceimpl<P: Provider<N>, N: Network> TestTokenInstance<P, N>
Event filters.
impl<P: Provider<N>, N: Network> TestTokenInstance<P, N>
Event filters.
Sourcepub fn event_filter<E: SolEvent>(&self) -> Event<&P, E, N>
pub fn event_filter<E: SolEvent>(&self) -> Event<&P, E, N>
Creates a new event filter using this contract instance’s provider and address.
Note that the type can be any event, not just those defined in this contract. Prefer using the other methods for building type-safe event filters.