Module error

Module error 

Enums

DexError
ProviderError
Error returned by the RPC provider as a result of call or transaction execution.
RevertReason
Call/transaction revert reason decoded by the provided known ABI or in a generic raw form if can not be decoded.