RevertReason

Enum RevertReason 

pub enum RevertReason<R> {
    Known(R),
    Generic(String),
    Unknown,
}
Call/transaction revert reason decoded by the provided known ABI or in a generic raw form if can not be decoded.

Variants



Known(R)



Generic(String)



Unknown