pub struct OrderBookView<'a> { /* private fields */ }Expand description
View of an order book. Can be rendered as plain table or compact L3 representation limited by depth and number of orders per level.
Implementations
Sourceimpl<'a> OrderBookView<'a>
impl<'a> OrderBookView<'a>
Sourcepub fn highlighted_by(self, highlight: &'a dyn OrderHighlight) -> Self
pub fn highlighted_by(self, highlight: &'a dyn OrderHighlight) -> Self
Repaints the orders highlight picks out, see OrderHighlight.