pub struct OrderEvent {
pub perpetual_id: PerpetualId,
pub account_id: AccountId,
pub request_id: Option<RequestId>,
pub client_order_id: Option<RequestId>,
pub order_id: Option<OrderId>,
pub builder: Option<BuilderAttribution>,
pub type: OrderEventType,
}Expand description
Order book state mutation event.
Fields
perpetual_id: PerpetualIdID of the perpetual contract of the order.
account_id: AccountIdID of the account issued the order.
request_id: Option<RequestId>ID of the request resulted in this event, if knonw.
client_order_id: Option<RequestId>Client order ID, if knonw.
order_id: Option<OrderId>ID of the order affected, if knonw.
builder: Option<BuilderAttribution>Builder the order is attributed to, with the fee rate it charges, if any.
Available on contract v1.1.7.4+ for orders whose placement was observed in the event stream or recovered from the initial snapshot.
type: OrderEventTypeType of the event with corresponding details.