Module testing

Module testing 

Local Anvil-based testing environment.

TestExchange spins up Anvil instance with collateral token and exchange smart contracts deployed and provides convenience methods for perpetual contracts setup and account creation.

TestPerp then can be used to configure perpetual contracts and post orders, while TestAccount provides basic information about exchange account.

Indexer wraps snapshot creation and event processing, while providing convenience methods for synchronization in tests.

Structs

IndexedState
Indexer
TestAccount
TestExchange
TestPerp

Functions

scale
usd