pub enum OrderType {
OpenLong,
OpenShort,
CloseLong,
CloseShort,
}Expand description
Type of the placed order.
Bid Order Types:
OrderType::OpenLongis used to open a long position (or to decrease, close, or invert a long position). The only restrictions applied are the user account must have sufficient collateral available.OrderType::CloseShortis a reduce only order type and can only be used to close all or part of an existing short position on the perpetual contract.
Ask Order Types:
OrderType::OpenShortis used to open a short position (or to decrease, close, or invert a short position). The only restrictions applied are the user account must have sufficient collateral available.OrderType::CloseLongis a reduce only order type and can only be used to close all or part of an existing long position on the perpetual contract.
Variants
Implementations