pub enum RequestType {
OpenLong,
OpenShort,
CloseLong,
CloseShort,
Cancel,
IncreasePositionCollateral,
Change,
}Expand description
Type of the order request.
RequestType::OpenLongis used to open a long position (or to decrease, close, or invert a long position). The only restrictions applied are the user account must have sufficient collateral available.RequestType::OpenShortis used to open a short position (or to decrease, close, or invert a short position). The only restrictions applied are the user account must have sufficient collateral available.RequestType::CloseLongis a reduce only order type and can only be used to close all or part of an existing long position on the perpetual contract.RequestType::CloseShortis a reduce only order type and can only be used to close all or part of an existing short position on the perpetual contract.RequestType::Cancelis used to cancel an existing order on the perpetual contract’s order book.RequestType::IncreasePositionCollateralis an operation to increase the collateral of an existing position in the event that it has insufficient margin or the account holder wishes to reduce leverage.RequestType::Changeis an operation to change parameters of an existing order, gas-efficiently.
Variants
Implementations