pub type FeeTier = u8;Expand description
Fee tier of an exchange account, indexing a crate::state::FeeSchedule.
Tier 0 is the base rate.
pub type FeeTier = u8;Fee tier of an exchange account, indexing a crate::state::FeeSchedule.
Tier 0 is the base rate.