Module error
perpl_
sdk
0.2.3
Module error
Module Items
Enums
In crate perpl_
sdk
perpl_sdk
Module
error
Enums

DexError
Provider
Error
Error returned by the RPC provider as a result of call or transaction execution.
Revert
Reason
Call/transaction revert reason decoded by the provided known ABI or in a generic raw form if can not be decoded.