pub enum OrderErrorType {
Show 27 variants
AccountFrozen,
AmountExceedsAvailableBalance(UD128, UD128),
CancelExistingInvalidCloseOrders,
CantChangeCloseOrder,
ChangeExpiredOrderNeedsNewExpiry,
CloseOrderExceedsPosition,
CloseOrderPositionMismatch,
ContractNotOperational,
CrossesBook,
ExceedsLastExecutionBlock,
ImmediateOrCancelExecuted,
InsuficientFundsForRecycleFee,
InvalidExpiryBlock,
InvalidOrderId,
MakerOrderSettlementFailed,
MaxMatchesReached,
MaximumAccountOrders,
OrderDoesNotExist,
OrderExtensionRejected,
OrderPostFailed(u16),
OrderSettlementImpliesInsolvent,
OrderSizeExceedsAvailableSize,
PostOrderUnderMinimum,
PriceOutOfRange,
SizeOutOfRange,
ValueExceedsMaximum,
WrongAccountForOrder,
}Expand description
Type of order request failure with corresponding details.
Variants
AccountFrozen
Account is frozen.
AmountExceedsAvailableBalance(UD128, UD128)
Required amount exceeds available balance.
CancelExistingInvalidCloseOrders
Existing close orders mismatch the actual position type and need to be cancelled before issuing new close orders.
CantChangeCloseOrder
Close orders can not be changed.
ChangeExpiredOrderNeedsNewExpiry
Provide new expiration to change expired order.
CloseOrderExceedsPosition
Close order size exceeds position size.
CloseOrderPositionMismatch
Close order side mismatches position type.
ContractNotOperational
Perpetual contract is not operational.
CrossesBook
Post-only order crosses the book.
ExceedsLastExecutionBlock
Current block exceeds last execution block specified for the order.
ImmediateOrCancelExecuted
Immediate-or-cancel order was not completely filled.
InsuficientFundsForRecycleFee
Available account balance can not cover recycling fee payment.
InvalidExpiryBlock
Current block exceeds expiration block specified for the order.
InvalidOrderId
Specified order ID is out of range.
MakerOrderSettlementFailed
Failed to settle maker order.
MaxMatchesReached
Maximum number of matches reached for the taker order.
MaximumAccountOrders
Account reached limit of orders to post.
OrderDoesNotExist
Order does not exist.
OrderExtensionRejected
Builder-code order extension failed a recoverable decode check (unknown envelope version, or a builder field out of range) on a batched or forwarded V2 request, so this single order was skipped while the rest of the batch proceeded.
OrderPostFailed(u16)
Order posting failed with status.
OrderSettlementImpliesInsolvent
Settlement of the order will render perpetual contract insolvent.
OrderSizeExceedsAvailableSize
Size of close order exceeds remaining position size.
PostOrderUnderMinimum
Order to be posted is under minimum amount.
PriceOutOfRange
Specified order price is out of range.
SizeOutOfRange
Specified order size is out of range.
ValueExceedsMaximum
Maximum PnL slippage value exceeds maximum of 65535
WrongAccountForOrder
Another account owns the order.