pub struct OrderBookView<'a> { /* private fields */ }Expand description
View of an order book. Can be rendered as plain table or compact L3 representation limited by depth and number of orders per level.